from mako.lookup import TemplateLookup
# Copyright (c) 2011 Cloudera, Inc. All rights reserved.
import os
"""
Utilities for rendering (with Mako) our templates.

The difference between the render_html and render_text
methods is that the former does HTML escaping by default,
to attempt to prevent against simple attacks.
"""

HTML_LOOKUP = TemplateLookup(
  directories=[os.path.join(os.path.dirname(__file__), "templates")],
  # escape HTML by default; disable with |n
  default_filters=['unicode', 'h'])

TEXT_LOOKUP = TemplateLookup(
  directories=[os.path.join(os.path.dirname(__file__), "templates")],
  default_filters=['unicode'])

def render_html(template_name, data):
  return render(template_name, data, HTML_LOOKUP)

def render_text(template_name, data):
  return render(template_name, data, TEXT_LOOKUP)

def render(template_name, data, lookup):
  """
  Renders template file using Mako with data.
  """
  template = lookup.get_template(template_name)
  return template.render(**data)
